AnySigner class

Constructors

AnySigner()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

sign(Uint8List bytes, int coin) → Uint8List
signerPlan(Uint8List bytes, int coin) → Uint8List
signJSON(String string, Uint8List bytes, int coin) → String
supportsJSON(int coin) → bool