BitcoinScript class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

data() → Uint8List
delete() → void
encode() → Uint8List
isPayToScriptHash() → bool
isPayToWitnessPublicKeyHash(Pointer<Void> script) → bool
isPayToWitnessScriptHash() → bool
isWitnessProgram() → bool
matchPayToPubkey() → Uint8List?
matchPayToPubkeyHash() → Uint8List?
matchPayToScriptHash() → Uint8List?
matchPayToWitnessPublicKeyHash() → Uint8List?
matchPayToWitnessScriptHash() → Uint8List?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scriptHash() → Uint8List
size() → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

equal(Pointer<Void> lhs, Pointer<Void> rhs) → bool
hashTypeForCoin(int coin) → int