HDWallet class

Constructors

HDWallet({int strength = 128, String passphrase = ""})
HDWallet.createWithData(Uint8List bytes, {String passphrase = ""})
HDWallet.createWithMnemonic(String mnemonic, {String passphrase = ""})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → void
getAddressForCoin(int coinType) → String
getDerivedKey(int coinType, int account, int change, int address) → PrivateKey
getExtendedPublicKey(int purpose, int coinType, int twHdVersion) → String
getKey(int coinType, String derivationPath) → PrivateKey
getKeyForCoin(int coinType) → PrivateKey
getMaterKey(int curve) → PrivateKey
mnemonic() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seed() → Uint8List
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited