PrivateKey class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

data() → Uint8List
delete() → void
getPublicKey(int curve, [bool compressed = false]) → PublicKey
getPublicKeyCurve25519() → PublicKey
getPublicKeyEd25519Cardano() → PublicKey
getPublicKeyNist256p1() → PublicKey
getPublicKeyNistEd25519() → PublicKey
getPublicKeyNistEd25519Blake2b() → PublicKey
getPublicKeySecp256k1(bool compressed) → PublicKey
getShareKey(PublicKey publicKey, int curve) → PublicKey
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Uint8List digest, int curve) → Uint8List
signAsDER(Uint8List digest, int curve) → Uint8List
signZilliqaSchnorr(Uint8List digest) → Uint8List
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isValid(Uint8List data, int curve) → bool

Constants

PrivateKeySize → const int