PublicKey class

Constructors

PublicKey.createWithData(Pointer<Void> data, int publicKeyType)

Properties

hashCode → int
The hash code for this object.
no setterinherited
pointer → Pointer<Void>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compressed() → Pointer<Void>
data() → Uint8List
delete() → void
description() → String
isCompressed() → bool
keyType() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
unCompressed() → Pointer<Void>
verify(Uint8List signature, Uint8List message) → bool
verifySchnorr(Uint8List signature, Uint8List message) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isValid(Uint8List data, int publivKeyType) → bool
recover(Uint8List signature, Uint8List message) → Pointer<Void>?