SegwitAddress class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → void
description() → String
hrp() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
witnessProgram() → Uint8List

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

equal() → bool
isValidString(String address) → bool