createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ManagedTokensRegisterMessage createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ManagedTokensRegisterMessage createEmptyInstance() => create();