Message class

Inheritance
  • Object
  • GeneratedMessage
  • Message

Constructors

Message({Message_Send? sendCoinsMessage, Message_Transfer? transferTokensMessage, Message_Delegate? stakeMessage, Message_Undelegate? unstakeMessage, Message_BeginRedelegate? restakeMessage, Message_WithdrawDelegationReward? withdrawStakeRewardMessage, Message_RawJSON? rawJsonMessage, Message_WasmTerraExecuteContractTransfer? wasmTerraExecuteContractTransferMessage, Message_WasmTerraExecuteContractSend? wasmTerraExecuteContractSendMessage, Message_THORChainSend? thorchainSendMessage, Message_WasmTerraExecuteContractGeneric? wasmTerraExecuteContractGeneric, Message_WasmExecuteContractTransfer? wasmExecuteContractTransferMessage, Message_WasmExecuteContractSend? wasmExecuteContractSendMessage, Message_WasmExecuteContractGeneric? wasmExecuteContractGeneric, Message_SignDirect? signDirectMessage, Message_AuthGrant? authGrant, Message_AuthRevoke? authRevoke, Message_MsgVote? msgVote})
factory
Message.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
Message.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

authGrant ↔ Message_AuthGrant
getter/setter pair
authRevoke ↔ Message_AuthRevoke
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
msgVote ↔ Message_MsgVote
getter/setter pair
rawJsonMessage ↔ Message_RawJSON
getter/setter pair
restakeMessage ↔ Message_BeginRedelegate
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendCoinsMessage ↔ Message_Send
getter/setter pair
signDirectMessage ↔ Message_SignDirect
getter/setter pair
stakeMessage ↔ Message_Delegate
getter/setter pair
thorchainSendMessage ↔ Message_THORChainSend
getter/setter pair
transferTokensMessage ↔ Message_Transfer
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
unstakeMessage ↔ Message_Undelegate
getter/setter pair
wasmExecuteContractGeneric ↔ Message_WasmExecuteContractGeneric
getter/setter pair
wasmExecuteContractSendMessage ↔ Message_WasmExecuteContractSend
getter/setter pair
wasmExecuteContractTransferMessage ↔ Message_WasmExecuteContractTransfer
getter/setter pair
wasmTerraExecuteContractGeneric ↔ Message_WasmTerraExecuteContractGeneric
getter/setter pair
wasmTerraExecuteContractSendMessage ↔ Message_WasmTerraExecuteContractSend
getter/setter pair
wasmTerraExecuteContractTransferMessage ↔ Message_WasmTerraExecuteContractTransfer
getter/setter pair
withdrawStakeRewardMessage ↔ Message_WithdrawDelegationReward
getter/setter pair

Methods

$_ensure<T>(int index) → T
For generated code only.
inherited
$_get<T>(int index, T defaultValue) → T
For generated code only.
inherited
$_getB(int index, bool defaultValue) → bool
For generated code only.
inherited
$_getBF(int index) → bool
For generated code only.
inherited
$_getI(int index, int defaultValue) → int
For generated code only.
inherited
$_getI64(int index) → Int64
For generated code only.
inherited
$_getIZ(int index) → int
For generated code only.
inherited
$_getList<T>(int index) → List<T>
For generated code only.
inherited
$_getMap<K, V>(int index) → Map<K, V>
For generated code only.
inherited
$_getN<T>(int index) → T
For generated code only.
inherited
$_getS(int index, String defaultValue) → String
For generated code only.
inherited
$_getSZ(int index) → String
For generated code only.
inherited
$_has(int index) → bool
For generated code only.
inherited
$_setBool(int index, bool value) → void
For generated code only.
inherited
$_setBytes(int index, List<int> value) → void
For generated code only.
inherited
$_setDouble(int index, double value) → void
For generated code only.
inherited
$_setFloat(int index, double value) → void
For generated code only.
inherited
$_setInt64(int index, Int64 value) → void
For generated code only.
inherited
$_setSignedInt32(int index, int value) → void
For generated code only.
inherited
$_setString(int index, String value) → void
For generated code only.
inherited
$_setUnsignedInt32(int index, int value) → void
For generated code only.
inherited
$_whichOneof(int oneofIndex) → int
inherited
addExtension(Extension extension, dynamic value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAuthGrant() → void
clearAuthRevoke() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearMessageOneof() → void
clearMsgVote() → void
clearRawJsonMessage() → void
clearRestakeMessage() → void
clearSendCoinsMessage() → void
clearSignDirectMessage() → void
clearStakeMessage() → void
clearThorchainSendMessage() → void
clearTransferTokensMessage() → void
clearUnstakeMessage() → void
clearWasmExecuteContractGeneric() → void
clearWasmExecuteContractSendMessage() → void
clearWasmExecuteContractTransferMessage() → void
clearWasmTerraExecuteContractGeneric() → void
clearWasmTerraExecuteContractSendMessage() → void
clearWasmTerraExecuteContractTransferMessage() → void
clearWithdrawStakeRewardMessage() → void
clone() → Message
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(Message)) → Message
Apply updates to a copy of this message.
override
createEmptyInstance() → Message
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureAuthGrant() → Message_AuthGrant
ensureAuthRevoke() → Message_AuthRevoke
ensureMsgVote() → Message_MsgVote
ensureRawJsonMessage() → Message_RawJSON
ensureRestakeMessage() → Message_BeginRedelegate
ensureSendCoinsMessage() → Message_Send
ensureSignDirectMessage() → Message_SignDirect
ensureStakeMessage() → Message_Delegate
ensureThorchainSendMessage() → Message_THORChainSend
ensureTransferTokensMessage() → Message_Transfer
ensureUnstakeMessage() → Message_Undelegate
ensureWasmExecuteContractGeneric() → Message_WasmExecuteContractGeneric
ensureWasmExecuteContractSendMessage() → Message_WasmExecuteContractSend
ensureWasmExecuteContractTransferMessage() → Message_WasmExecuteContractTransfer
ensureWasmTerraExecuteContractGeneric() → Message_WasmTerraExecuteContractGeneric
ensureWasmTerraExecuteContractSendMessage() → Message_WasmTerraExecuteContractSend
ensureWasmTerraExecuteContractTransferMessage() → Message_WasmTerraExecuteContractTransfer
ensureWithdrawStakeRewardMessage() → Message_WithdrawDelegationReward
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAuthGrant() → bool
hasAuthRevoke() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasMsgVote() → bool
hasRawJsonMessage() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasRestakeMessage() → bool
hasSendCoinsMessage() → bool
hasSignDirectMessage() → bool
hasStakeMessage() → bool
hasThorchainSendMessage() → bool
hasTransferTokensMessage() → bool
hasUnstakeMessage() → bool
hasWasmExecuteContractGeneric() → bool
hasWasmExecuteContractSendMessage() → bool
hasWasmExecuteContractTransferMessage() → bool
hasWasmTerraExecuteContractGeneric() → bool
hasWasmTerraExecuteContractSendMessage() → bool
hasWasmTerraExecuteContractTransferMessage() → bool
hasWithdrawStakeRewardMessage() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichMessageOneof() → Message_MessageOneof
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → Message
createRepeated() → PbList<Message>
getDefault() → Message