TWBitCoinAddressImpl class

Inheritance

Constructors

TWBitCoinAddressImpl()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create({String string = ""}) → Pointer<Void>
createWithData(Uint8List bytes) → Pointer<Void>
createWithPublicKey(Pointer<Void> publicKey, int prefix) → Pointer<Void>
delete(Pointer<Void> address) → void
description(Pointer<Void> address) → String
equal(Pointer<Void> lhs, Pointer<Void> rhs) → bool
isValid(Uint8List data) → bool
isValidString(String string) → bool
keyhash(Pointer<Void> address) → Uint8List
prefix(Pointer<Void> address) → int