TWString class abstract

Defines a resizable string.

The implementantion of these methods should be language-specific to minimize translation overhead. For instance it should be a jstring for Java and an NSString for Swift. Create allocates memory, the delete call should be called at the end to release memory.

Implementers

Constructors

TWString()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

TWStringCreateWithHexData(Pointer<Void> data) → Pointer<Utf8>
Creates a hexadecimal string from a block of data. It must be deleted at the end.
TWStringCreateWithRawBytes(Pointer<Uint8> bytes, int size) → Pointer<Utf8>
Creates a string from a raw byte array and size. It must be deleted at the end.
TWStringCreateWithUTF8Bytes(Pointer<Utf8> bytes) → Pointer<Utf8>
Creates a TWString from a null-terminated UTF8 byte array. It must be deleted at the end.
TWStringDelete(Pointer<Utf8> string) → void
Deletes a string created with a TWStringCreate* method and frees the memory.
TWStringEqual(Pointer<Utf8> lhs, Pointer<Utf8> rhs) → bool
Determines whether two string blocks are equal.
TWStringGet(Pointer<Utf8> string, int index) → int
Returns the byte at the provided index.
TWStringSize(Pointer<Utf8> string) → int
Returns the string size in bytes.
TWStringUTF8Bytes(Pointer<Utf8> string) → Pointer<Utf8>
Returns the raw pointer to the string's UTF8 bytes (null-terminated).