TWStringImpl class

Inheritance

Constructors

TWStringImpl()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

delete(Pointer<Utf8> string) → void
size(Pointer<Utf8> string) → int
toDartString(Pointer<Utf8> value) → String
toTWString(String value) → Pointer<Utf8>
It must be deleted at the end.
twStringEqual(Pointer<Utf8> lhs, Pointer<Utf8> rhs) → bool